@@ -1,15 +1,18 @@
-use strict;
+use v5.32;
+use utf8;
 use warnings;
+use open qw(:std :utf8);
+no feature qw(indirect);
+use feature qw(signatures);
+no warnings qw(experimental::signatures);
+
 package Net::Amazon::SignatureVersion4;
-{
-  $Net::Amazon::SignatureVersion4::VERSION = '0.006';
-}
+$Net::Amazon::SignatureVersion4::VERSION = '0.007';
 use MooseX::App qw(Config);
-use Digest::SHA qw(sha256_hex hmac_sha256_hex hmac_sha256 hmac_sha256_base64);
 use POSIX qw(strftime);
+use Digest::SHA qw(sha256_hex hmac_sha256_hex hmac_sha256 hmac_sha256_base64);
 use URI::Encode;
 use HTTP::Date;
-use 5.010;
 
 # ABSTRACT: Signs requests using Amazon's Signature Version 4.
 
@@ -246,19 +249,21 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::SignatureVersion4 - Signs requests using Amazon's Signature Version 4.
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
     use Net::Amazon::SignatureVersion4;
 
-    my $sig=new Net::Amazon::SignatureVersion4();
+    my $sig=Net::Amazon::SignatureVersion4->new();
     my $hr=HTTP::Request->new('GET','http://glacier.us-west-2.amazonaws.com/-/vaults', [ 
 				   'Host', 'glacier.us-west-2.amazonaws.com', 
 				   'Date', strftime("%Y%m%dT%H%M%SZ",gmtime(time())) , 
@@ -335,7 +340,7 @@ Charles A. Wimmer <charles@wimmer.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Charles A. Wimmer.
+This software is Copyright (c) 2022 by Charles A. Wimmer.
 
 This is free software, licensed under:
 
